==> stimulsoft-forms-2024.2.5.tgz: package/README.md <==
﻿# Component for Stimulsoft Forms

The Forms component is designed to create and view forms in the web browser. The Forms tool easily integrates into your project or application, has an intuitive and user-friendly interface, and allows you to create rich form templates.

There are three levels of work with fillable forms: a) application developer, b) form creator, and c) user. Integrating and deploying our product in your application or project is the first step. We have tried to simplify this stage. To do this, install the required package from the repository or download the package from our website and add the necessary libraries. No additional modules or particular extensions are needed.

Learn more about [**Stimulsoft Forms**](https://www.stimulsoft.com/en/products/forms)

# How to install

``
npm install stimulsoft-forms
``
# Integration

We offer a product for creating editable PDF forms in your Angular applications. On the product pages, you can find more information about integration options, how our products may work in your applications, licensing terms and conditions, and much more.  


We tried to make product integration in the project as simple as possible. You should install the necessary package from the NuGet repository or download the package from our website to your computer and add the libraries required for the project. No additional modules and particular extensions are needed. All you need, the product already has. The product supports .NET Framework 4.5.2 and above, or .NET Core 3.1, .NET 5, .NET 6, and .NET 7.

[NuGet repository](https://www.nuget.org/packages/Stimulsoft.Forms.Web)

# Live Demo

We prepared many templates of fillable forms, that you can explore and edit in our online demo. Try the [**Live Demo**](https://demo.stimulsoft.com/?viewmode=forms)  now

# Video and Documentation

We prepared many videos about how our software works. See the video on our [**YouTube channel**](https://www.youtube.com/c/StimulsoftVideos/videos)

# Helpful links

[**Download**](https://www.stimulsoft.com/en/downloads)

[**Online Store**](https://www.stimulsoft.com/en/online-store#embedded/forms)

[**License Info**](https://github.com/stimulsoft/Samples-Forms.WEB-for-ASP.NET-Core/blob/main/LICENSE.md)


# Keywords

- **Stimulsoft**
- **PDF**
- **Angular**
- **Forms**

==> stimulsoft-forms-2024.3.4.tgz: package/README.md <==
﻿# Component for Stimulsoft PDF Forms

The Forms component is designed to create and view forms in the web browser. The Forms tool easily integrates into your project or application, has an intuitive and user-friendly interface, and allows you to create rich form templates.

There are three levels of work with fillable forms: a) application developer, b) form creator, and c) user. Integrating and deploying our product in your application or project is the first step. We have tried to simplify this stage. To do this, install the required package from the repository or download the package from our website and add the necessary libraries. No additional modules or particular extensions are needed.

Learn more about [**Stimulsoft PDF Forms**](https://www.stimulsoft.com/en/products/forms)

# How to install

``
npm install stimulsoft-forms
``
# Integration

We offer a product for creating editable PDF forms in your Angular applications. On the product pages, you can find more information about integration options, how our products may work in your applications, licensing terms and conditions, and much more.  


We tried to make product integration in the project as simple as possible. You should install the necessary package from the NuGet repository or download the package from our website to your computer and add the libraries required for the project. No additional modules and particular extensions are needed. All you need, the product already has. The product supports .NET Framework 4.5.2 and above, or .NET Core 3.1, .NET 5, .NET 6, and .NET 7.

[NuGet repository](https://www.nuget.org/packages/Stimulsoft.PDF.Forms)

# Live Demo

We prepared many templates of fillable forms, that you can explore and edit in our online demo. Try the [**Live Demo**](https://demo.stimulsoft.com/?viewmode=forms)  now

# Video and Documentation

We prepared many videos about how our software works. See the video on our [**YouTube channel**](https://www.youtube.com/c/StimulsoftVideos/videos)

# Helpful links

[**Download**](https://www.stimulsoft.com/en/downloads)

[**Online Store**](https://www.stimulsoft.com/en/online-store#embedded/forms)

[**License Info**](https://github.com/stimulsoft/Samples-PDF-Forms-for-ASP.NET-Core/blob/main/LICENSE.md)


# Keywords

- **Stimulsoft**
- **PDF**
- **Angular**
- **Forms**
